#include <med.h>
#include <med_config.h>
#include <med_outils.h>

med_int MEDnLien   (_IN med_idt fid ) {

  int n=0;
  med_idt datagroup=0;

  _MEDmodeErreurVerrouiller();

  if ( (datagroup = _MEDdatagroupOuvrir(fid,MED_LIENS)) < 0) 
    return 0;
  else
    if (datagroup) if ( _MEDdatagroupFermer(datagroup) < 0) {
      MESSAGE("Impossible de fermer le datagroup : ");
      ISCRUTE_int(datagroup); return -1; 
    }
  
  if (  _MEDnObjets(fid,MED_LIENS,&n) < 0 ) return -1;

  return (med_int) n;

}
